X-Git-Url: http://git.ithinksw.org/extjs.git/blobdiff_plain/c930e9176a5a85509c5b0230e2bff5c22a591432..0494b8d9b9bb03ab6c22b34dae81261e3cd7e3e6:/src/widgets/chart/FlashComponent.js?ds=sidebyside
diff --git a/src/widgets/chart/FlashComponent.js b/src/widgets/chart/FlashComponent.js
index 9fff3518..1398c310 100644
--- a/src/widgets/chart/FlashComponent.js
+++ b/src/widgets/chart/FlashComponent.js
@@ -1,8 +1,8 @@
/*!
- * Ext JS Library 3.0.0
- * Copyright(c) 2006-2009 Ext JS, LLC
- * licensing@extjs.com
- * http://www.extjs.com/license
+ * Ext JS Library 3.3.1
+ * Copyright(c) 2006-2010 Sencha Inc.
+ * licensing@sencha.com
+ * http://www.sencha.com/license
*/
/**
* @class Ext.FlashComponent
@@ -13,9 +13,9 @@
Ext.FlashComponent = Ext.extend(Ext.BoxComponent, {
/**
* @cfg {String} flashVersion
* Indicates the version the flash content was published for. Defaults to '9.0.45'.
*/
- flashVersion : '9.0.45',
+ flashVersion : '9.0.115',
/**
* @cfg {String} backgroundColor
@@ -29,6 +29,19 @@ Ext.FlashComponent = Ext.extend(Ext.BoxComponent, {
*/
wmode: 'opaque',
+ /**
+ * @cfg {Object} flashVars
+ * A set of key value pairs to be passed to the flash object as flash variables. Defaults to undefined.
+ */
+ flashVars: undefined,
+
+ /**
+ * @cfg {Object} flashParams
+ * A set of key value pairs to be passed to the flash object as parameters. Possible parameters can be found here:
+ * http://kb2.adobe.com/cps/127/tn_12701.html Defaults to undefined.
+ */
+ flashParams: undefined,
+
/**
* @cfg {String} url
* The URL of the chart to include. Defaults to undefined.
@@ -48,21 +61,28 @@ Ext.FlashComponent = Ext.extend(Ext.BoxComponent, {
initComponent : function(){
Ext.FlashComponent.superclass.initComponent.call(this);
- this.addEvents('initialize');
+ this.addEvents(
+ /**
+ * @event initialize
+ *
+ * @param {Chart} this
+ */
+ 'initialize'
+ );
},
onRender : function(){
Ext.FlashComponent.superclass.onRender.apply(this, arguments);
- var params = {
+ var params = Ext.apply({
allowScriptAccess: 'always',
bgcolor: this.backgroundColor,
wmode: this.wmode
- }, vars = {
+ }, this.flashParams), vars = Ext.apply({
allowedDomain: document.location.hostname,
- elementID: this.getId(),
- eventHandler: 'Ext.FlashEventProxy.onEvent'
- };
+ YUISwfId: this.getId(),
+ YUIBridgeCallback: 'Ext.FlashEventProxy.onEvent'
+ }, this.flashVars);
new swfobject.embedSWF(this.url, this.id, this.swfWidth, this.swfHeight, this.flashVersion,
this.expressInstall ? Ext.FlashComponent.EXPRESS_INSTALL_URL : undefined, vars, params);
@@ -13,9 +13,9 @@
/**
* @cfg {String} flashVersion
- * Indicates the version the flash content was published for. Defaults to '9.0.45'.
+ * Indicates the version the flash content was published for. Defaults to '9.0.115'.
*/